from setuptools import setup

setup(
    name='FrameWorkConsumo',
    version='0.0.1',

    url='https://github.com/Dauerrr/FrameworkConsumo',
    author='Pedro Dauer',
    author_email='pedro.dauer2003@gmail.com',

    py_modules=['descritor'],
    install_requires=[
    'pandas',
    'requests',
],
)
